@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
-71 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+71 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 // For instance:
@@ -25,6 +25,7 @@
 
 #include <libglom/connectionpool.h>
 #include <libglom/connectionpool_backends/postgres_central.h>
+#include <libglom/connectionpool_backends/mysql_central.h>
 #include <libglom/init.h>
 #include <libglom/privs.h>
 #include <libglom/utils.h>
@@ -49,12 +50,20 @@ public:
   Glib::ustring m_arg_server_username;
   Glib::ustring m_arg_server_password;
   Glib::ustring m_arg_server_database;
+
+#ifdef GLOM_ENABLE_MYSQL
+  bool m_arg_use_mysql;
+#endif //GLOM_ENABLE_MYSQL
 };
 
 GlomCreateOptionGroup::GlomCreateOptionGroup()
 : Glib::OptionGroup("glom_create_from_example", _("Glom options"), _("Command-line options")),
   m_arg_version(false),
   m_arg_server_port(0)
+#ifdef GLOM_ENABLE_MYSQL
+  ,
+  m_arg_use_mysql(false)
+#endif //GLOM_ENABLE_MYSQL
 {
   Glib::OptionEntry entry;
 
@@ -83,6 +92,14 @@ GlomCreateOptionGroup::GlomCreateOptionGroup()
   entry.set_short_name('d');
   entry.set_description(_("The specific database on the PostgreSQL server (Optional)."));
   add_entry(entry, m_arg_server_database);
+
+
+#ifdef GLOM_ENABLE_MYSQL
+  entry.set_long_name("use-mysql");
+  entry.set_short_name('m');
+  entry.set_description(_("Use MySQL instead of PostgreSQL."));
+  add_entry(entry, m_arg_use_mysql);
+#endif //GLOM_ENABLE_MYSQL
 }
 
 static void print_options_hint()
@@ -167,7 +184,7 @@ int main(int argc, char* argv[])
 
 #ifdef G_OS_WIN32
   const char* password = "";
-  std::cerr << _("Error: getpass() is not implemented in the Windows build. The connection will fail." << std::endl;
+  std::cerr << "Error: getpass() is not implemented in the Windows build. The connection will fail." << std::endl;
 #else
   const char* password = ::getpass(prompt.c_str());
 #endif
@@ -177,19 +194,46 @@ int main(int argc, char* argv[])
 
   //Specify the backend and backend-specific details to be used by the connectionpool.
   //This is usually done by ConnectionPool::setup_from_document():
-  Glom::ConnectionPoolBackends::PostgresCentralHosted* backend = 
-    new Glom::ConnectionPoolBackends::PostgresCentralHosted;
-  backend->set_host(group.m_arg_server_hostname);
-
-  //Use a specified port, or try all suitable ports:
-  if(group.m_arg_server_port)
+  Glom::ConnectionPoolBackends::Backend* backend = 0;
+#ifdef GLOM_ENABLE_MYSQL
+  if(group.m_arg_use_mysql)
   {
-    backend->set_port(group.m_arg_server_port);
-    backend->set_try_other_ports(false);
+    //TODO: Move some of the *CentralHosted API into a multiply-inherited Server base class,
+    //to avoid the duplication?
+    Glom::ConnectionPoolBackends::MySQLCentralHosted* derived_backend = new Glom::ConnectionPoolBackends::MySQLCentralHosted;
+
+    //Use a specified port, or try all suitable ports:
+    if(group.m_arg_server_port)
+    {
+      derived_backend->set_port(group.m_arg_server_port);
+      derived_backend->set_try_other_ports(false);
+    }
+    else
+    {
+      derived_backend->set_try_other_ports(true);
+    }
+
+    derived_backend->set_host(group.m_arg_server_hostname);
+    backend = derived_backend;
   }
   else
+#endif //GLOM_ENABLE_MYSQL
   {
-    backend->set_try_other_ports(true);
+    Glom::ConnectionPoolBackends::PostgresCentralHosted* derived_backend = new Glom::ConnectionPoolBackends::PostgresCentralHosted;
+
+    //Use a specified port, or try all suitable ports:
+    if(group.m_arg_server_port)
+    {
+      derived_backend->set_port(group.m_arg_server_port);
+      derived_backend->set_try_other_ports(false);
+    }
+    else
+    {
+      derived_backend->set_try_other_ports(true);
+    }
+
+    derived_backend->set_host(group.m_arg_server_hostname);
+    backend = derived_backend;
   }
 
   connection_pool->set_user(group.m_arg_server_username);
