@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <glom/mode_data/box_data_calendar_related.h>
@@ -54,7 +54,9 @@ Box_Data_Calendar_Related::Box_Data_Calendar_Related()
   //m_calendar.add_events(Gdk::BUTTON_PRESS_MASK); //Allow us to catch button_press_event and button_release_event
   m_calendar.signal_button_press_event().connect_notify( sigc::mem_fun(*this, &Box_Data_Calendar_Related::on_calendar_button_press_event) );
 
-  m_layout_name = "list_related_calendar"; //TODO: We need a unique name when 2 portals use the same table.
+  //We do not actually use this,
+  //so it is a bug if this appears in the .glom file:
+  m_layout_name = "NotUsedlist_related_calendar";
 }
 
 Box_Data_Calendar_Related::~Box_Data_Calendar_Related()
